@@ -2,7 +2,9 @@
 #
 # This file is part of Pod-Markdown
 #
-# This software is copyright (c) 2004 by Marcel Gruenauer.
+# This software is copyright (c) 2009-2011 by Marcel Gruenauer.
+#
+# This software is copyright (c) 2011 by Randy Stauner.
 #
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
@@ -12,15 +14,16 @@ use strict;
 use warnings;
 
 package Pod::Markdown;
-# git description: v2.001-2-gadb8327
-$Pod::Markdown::VERSION = '2.002';
-BEGIN {
-  $Pod::Markdown::AUTHORITY = 'cpan:RWSTAUNER';
-}
-# ABSTRACT: Convert POD to Markdown
+# git description: v2.002-31-gf40f37b
 
+our $AUTHORITY = 'cpan:RWSTAUNER';
+# ABSTRACT: Convert POD to Markdown
+$Pod::Markdown::VERSION = '3.000';
 use Pod::Simple 3.14 (); # external links with text
 use parent qw(Pod::Simple::Methody);
+use Encode ();
+
+my $NBSP = chr(0xA0);
 
 our %URL_PREFIXES = (
   sco      => 'http://search.cpan.org/perldoc?',
@@ -29,6 +32,77 @@ our %URL_PREFIXES = (
 );
 $URL_PREFIXES{perldoc} = $URL_PREFIXES{metacpan};
 
+#{
+  our $HAS_HTML_ENTITIES;
+
+  # Stolen from Pod::Simple::XHTML 3.28. {{{
+
+  BEGIN {
+    $HAS_HTML_ENTITIES = eval "require HTML::Entities; 1";
+  }
+
+  my %entities = (
+    q{>} => 'gt',
+    q{<} => 'lt',
+    q{'} => '#39',
+    q{"} => 'quot',
+    q{&} => 'amp',
+  );
+
+  sub encode_entities {
+    my $self = shift;
+    my $ents = $self->html_encode_chars;
+    return HTML::Entities::encode_entities( $_[0], $ents ) if $HAS_HTML_ENTITIES;
+    if (defined $ents) {
+        $ents =~ s,(?<!\\)([]/]),\\$1,g;
+        $ents =~ s,(?<!\\)\\\z,\\\\,;
+    } else {
+        $ents = join '', keys %entities;
+    }
+    my $str = $_[0];
+    $str =~ s/([$ents])/'&' . ($entities{$1} || sprintf '#x%X', ord $1) . ';'/ge;
+    return $str;
+  }
+
+  # }}}
+
+  # Add a few very common ones for consistency and readability
+  # (in case HTML::Entities isn't available).
+  %entities = (
+    $NBSP     => 'nbsp',
+    chr(0xA9) => 'copy',
+    %entities
+  );
+
+  sub __entity_encode_ord_he {
+    my $chr = chr $_[0];
+    # Skip the encode_entities() logic and go straight for the substitution
+    # since we already have the char we know we want replaced.
+    # Both the hash and the function are documented as exportable (so should be reliable).
+    return $HTML::Entities::char2entity{ $chr } || HTML::Entities::num_entity( $chr );
+  }
+  sub __entity_encode_ord_basic {
+    return '&' . ($entities{chr $_[0]} || sprintf '#x%X', $_[0]) . ';';
+  }
+
+  # From HTML::Entities 3.69
+  my $DEFAULT_ENTITY_CHARS = '^\n\r\t !\#\$%\(-;=?-~';
+
+#}
+
+# Use hash for simple "exists" check in `new` (much more accurate than `->can`).
+my %attributes = map { ($_ => 1) }
+  qw(
+    html_encode_chars
+    match_encoding
+    output_encoding
+    man_url_prefix
+    perldoc_url_prefix
+    perldoc_fragment_format
+    markdown_fragment_format
+    include_meta_tags
+  );
+
 
 sub new {
   my $class = shift;
@@ -38,17 +112,33 @@ sub new {
   $self->preserve_whitespace(1);
   $self->accept_targets(qw( markdown html ));
 
-  my $data = $self->_private;
   while( my ($attr, $val) = each %args ){
-    $data->{ $attr } = $val;
+    # NOTE: Checking exists on a private var means we don't allow Pod::Simple
+    # attributes to be set this way.  It's not very consistent, but I think
+    # I'm ok with that for now since there probably aren't many Pod::Simple attributes
+    # being changed besides `output_*` which feel like API rather than attributes.
+    # We'll see.
+    # This is currently backward-compatible as we previously just put the attribute
+    # into the private stash so anything unknown was silently ignored.
+    # We could open this up to `$self->can($attr)` in the future if that seems better
+    # but it tricked me when I was testing a misspelled attribute name
+    # which also happened to be a Pod::Simple method.
+
+    exists $attributes{ $attr } or
+      # Provide a more descriptive message than "Can't locate object method".
+      warn("Unknown argument to ${class}->new(): '$attr'"), next;
+
+    # Call setter.
+    $self->$attr($val);
   }
 
+    # TODO: move this logic to setter (and call _prepare_fragment_format).
     for my $type ( qw( perldoc man ) ){
         my $attr  = $type . '_url_prefix';
         # Use provided argument or default alias.
         my $url = $self->$attr || $type;
         # Expand alias if defined (otherwise use url as is).
-        $data->{ $attr } = $URL_PREFIXES{ $url } || $url;
+        $self->$attr( $URL_PREFIXES{ $url } || $url );
     }
 
     $self->_prepare_fragment_formats;
@@ -59,25 +149,47 @@ sub new {
 ## Attribute accessors ##
 
 
-my @attr = qw(
-  man_url_prefix
-  perldoc_url_prefix
-  perldoc_fragment_format
-  markdown_fragment_format
-  include_meta_tags
-);
+sub html_encode_chars {
+  my $self  = shift;
+  my $stash = $self->_private;
 
-{
-  no strict 'refs'; ## no critic
-  foreach my $attr ( @attr ){
-    *$attr = sub { return $_[0]->_private->{ $attr } };
+  # Setter.
+  if( @_ ){
+    # If false ('', 0, undef), disable.
+    if( !$_[0] ){
+      delete $stash->{html_encode_chars};
+      $stash->{encode_amp}  = 1;
+      $stash->{encode_lt}   = 1;
+    }
+    else {
+      # Special case boolean '1' to mean "all".
+      # If we have HTML::Entities, undef will use the default.
+      # Without it, we need to specify so that we use the same list (for consistency).
+      $stash->{html_encode_chars} = $_[0] eq '1' ? ($HAS_HTML_ENTITIES ? undef : $DEFAULT_ENTITY_CHARS) : $_[0];
+
+      # If [char] doesn't get encoded, we need to do it ourselves.
+      $stash->{encode_amp}  = ($self->encode_entities('&') eq '&');
+      $stash->{encode_lt}   = ($self->encode_entities('<') eq '<');
+    }
+    return;
   }
+
+  # Getter.
+  return $stash->{html_encode_chars};
 }
 
+
+# I prefer ro-accessors (immutability!) but it can be confusing
+# to not support the same API as other Pod::Simple classes.
+
+# NOTE: Pod::Simple::_accessorize is not a documented public API.
+# Skip any that have already been defined.
+__PACKAGE__->_accessorize(grep { !__PACKAGE__->can($_) } keys %attributes);
+
 sub _prepare_fragment_formats {
   my ($self) = @_;
 
-  foreach my $attr ( @attr ){
+  foreach my $attr ( keys %attributes ){
     next unless $attr =~ /^(\w+)_fragment_format/;
     my $type = $1;
     my $format = $self->$attr;
@@ -112,7 +224,7 @@ sub _prepare_fragment_formats {
       unless $self->can($prefix . $format);
 
     # Save it.
-    $self->_private->{ $attr } = $format;
+    $self->$attr($format);
   }
 
   return;
@@ -128,6 +240,10 @@ sub _prepare_fragment_formats {
 # so we don't want to start now.
 sub parse_from_file {
   my ($self, $file) = @_;
+
+  # TODO: Check that all dependent cpan modules use the Pod::Simple API
+  # then add a deprecation warning here to avoid confusion.
+
   $self->output_string(\($self->{_as_markdown_}));
   $self->parse_file($file);
 }
@@ -145,6 +261,8 @@ sub _private {
     stacks      => [],
     states      => [{}],
     link        => [],
+    encode_amp  => 1,
+    encode_lt   => 1,
   };
 }
 
@@ -183,6 +301,9 @@ sub _save {
 
 sub _save_line {
   my ($self, $text) = @_;
+
+  $text = $self->_process_escapes($text);
+
   $self->_save($text . $/);
 }
 
@@ -217,6 +338,9 @@ sub _indent {
   return $text;
 }
 
+# as_markdown() exists solely for backward compatibility
+# and requires having called parse_from_file() to be useful.
+
 
 sub as_markdown {
     my ($parser, %args) = @_;
@@ -268,6 +392,7 @@ sub _build_markdown_head {
 # just the ones that start a line (likewise for plus and dot).
 # (Those will all be handled by _escape_paragraph_markdown).
 
+
 # Backslash escape markdown characters to avoid having them interpreted.
 sub _escape_inline_markdown {
   local $_ = $_[1];
@@ -297,17 +422,128 @@ sub _escape_paragraph_markdown {
     return $_;
 }
 
+
+# Additionally Markdown allows inline html so we need to escape things that look like it.
+# While _some_ Markdown processors handle backslash-escaped html,
+# [Daring Fireball](http://daringfireball.net/projects/markdown/syntax) states distinctly:
+# > In HTML, there are two characters that demand special treatment: < and &...
+# > If you want to use them as literal characters, you must escape them as entities, e.g. &lt;, and &amp;.
+
+# It goes on to say:
+# > Markdown allows you to use these characters naturally,
+# > taking care of all the necessary escaping for you.
+# > If you use an ampersand as part of an HTML entity,
+# > it remains unchanged; otherwise it will be translated into &amp;.
+# > Similarly, because Markdown supports inline HTML,
+# > if you use angle brackets as delimiters for HTML tags, Markdown will treat them as such.
+
+# In order to only encode the occurrences that require it (something that
+# could be interpreted as an entity) we escape them all so that we can do the
+# suffix test later after the string is complete (since we don't know what
+# strings might come after this one).
+
+my %_escape =
+  map {
+    my ($k, $v) = split /:/;
+    # Put the "code" marker before the char instead of after so that it doesn't
+    # get confused as the $2 (which is what requires us to entity-encode it).
+    # ( "XsX", "XcsX", "X(c?)sX" )
+    my ($s, $code, $re) = map { "\0$_$v\0" } '', map { ($_, '('.$_.'?)') } 'c';
+
+    (
+      $k         => $s,
+      $k.'_code' => $code,
+      $k.'_re'   => qr/$re/,
+    )
+  }
+    qw( amp:& lt:< );
+
+# Make the values of this private var available to the tests.
+sub __escape_sequences { %_escape }
+
+
+# HTML-entity encode any characters configured by the user.
+# If that doesn't include [&<] then we escape those chars so we can decide
+# later if we will entity-encode them or put them back verbatim.
+sub _encode_or_escape_entities {
+  my $self  = $_[0];
+  my $stash = $self->_private;
+  local $_  = $_[1];
+
+  if( $stash->{encode_amp} ){
+    if( exists($stash->{html_encode_chars}) ){
+      # Escape all amps for later processing.
+      # Pass intermediate strings to entity encoder so that it doesn't
+      # process any of the characters of our escape sequences.
+      # Use -1 to get "as many fields as possible" so that we keep leading and
+      # trailing (possibly empty) fields.
+      $_ = join $_escape{amp}, map { $self->encode_entities($_) } split /&/, $_, -1;
+    }
+    else {
+      s/&/$_escape{amp}/g;
+    }
+  }
+  elsif( exists($stash->{html_encode_chars}) ){
+    $_ = $self->encode_entities($_);
+  }
+
+  s/</$_escape{lt}/g
+    if $stash->{encode_lt};
+
+  return $_;
+}
+
+# Process any escapes we put in the text earlier,
+# now that the text is complete (end of a block).
+sub _process_escapes {
+  my $self  = $_[0];
+  my $stash = $self->_private;
+  local $_  = $_[1];
+
+  # The patterns below are taken from Markdown.pl 1.0.1 _EncodeAmpsAndAngles().
+  # In this case we only want to encode the ones that Markdown won't.
+  # This is overkill but produces nicer looking text (less escaped entities).
+  # If it proves insufficent then we'll just encode them all.
+
+  # $1: If the escape was in a code sequence, simply replace the original.
+  # $2: If the unescaped value would be followed by characters
+  #     that could be interpreted as html, entity-encode it.
+  # else: The character is safe to leave bare.
+
+  # Neither currently allows $2 to contain '0' so bool tests are sufficient.
+
+  if( $stash->{encode_amp} ){
+    # Encode & if succeeded by chars that look like an html entity.
+    s,$_escape{amp_re}((?:#?[xX]?(?:[0-9a-fA-F]+|\w+);)?),
+      $1 ? '&'.$2 : $2 ? '&amp;'.$2 : '&',egos;
+  }
+
+  if( $stash->{encode_lt} ){
+    # Encode < if succeeded by chars that look like an html tag.
+    s,$_escape{lt_re}((?:[a-z/?\$!])?),
+      $1 ? '<'.$2 : $2 ?  '&lt;'.$2 : '<',egos;
+  }
+
+  return $_;
+}
+
+
 ## Parsing ##
 
 sub handle_text {
-  my ($self, $text) = @_;
+  my $self  = $_[0];
+  my $stash = $self->_private;
+  local $_  = $_[1];
 
-  # Markdown is for html, so use html entities.
-  $text =~ s/ /&nbsp;/g
-    if $self->_private->{nbsp};
+  # NOTE: If this document ends up forcing ascii encoding (which might not be known at this
+  # point) and this is a code block, these will get entity-encoded which will be
+  # wrong.  In order to solve that we might have to escape them like we do [&<]
+  # or simply ignore nbsp if no_escape.
+  s/ /$NBSP/g
+    if $stash->{nbsp};
 
-  # Unless we're in a code span or verbatim block.
-  unless( $self->_private->{no_escape} ){
+  # Unless we're in a code span, verbatim block, or formatted region.
+  unless( $stash->{no_escape} ){
 
     # We could, in theory, alter what gets escaped according to context
     # (for example, escape square brackets (but not parens) inside link text).
@@ -316,11 +552,22 @@ sub handle_text {
     # For now just escape everything.
 
     # Don't let literal characters be interpreted as markdown.
-    $text = $self->_escape_inline_markdown($text);
+    $_ = $self->_escape_inline_markdown($_);
+
+    # Entity-encode (or escape for later processing) necessary/desired chars.
+    $_ = $self->_encode_or_escape_entities($_);
 
   }
+  # If this _is_ a code section, do limited/specific handling.
+  else {
+    # Always escaping these chars ensures that we won't mangle the text
+    # in the unlikely event that a sequence matching our escape occurred in the
+    # input stream (since we're going to escape it and then unescape it).
+    s/&/$_escape{amp_code}/gos if $stash->{encode_amp};
+    s/</$_escape{lt_code}/gos  if $stash->{encode_lt};
+  }
 
-  $self->_save($text);
+  $self->_save($_);
 }
 
 sub start_Document {
@@ -342,7 +589,36 @@ sub   end_Document {
     unshift @doc, $self->_build_markdown_head, ($/ x 2);
   }
 
-  print { $self->{output_fh} } @doc;
+  if( my $encoding = $self->_get_output_encoding ){
+    # Do the check outside the loop(s) for efficiency.
+    my $ents = $HAS_HTML_ENTITIES ? \&__entity_encode_ord_he : \&__entity_encode_ord_basic;
+    # Iterate indices to avoid copying large strings.
+    for my $i ( 0 .. $#doc ){
+      print { $self->{output_fh} } Encode::encode($encoding, $doc[$i], $ents);
+    }
+  }
+  else {
+    print { $self->{output_fh} } @doc;
+  }
+}
+
+sub _get_output_encoding {
+  my ($self) = @_;
+
+  # If 'match_encoding' is set we need to return an encoding.
+  # If pod has no =encoding, Pod::Simple will guess if it sees a high-bit char.
+  # If there are no high-bit chars, encoding is undef.
+  # Use detected_encoding() rather than encoding() because if Pod::Simple
+  # can't use whatever encoding was specified, we probably can't either.
+  # Fallback to 'o_e' if no match is found.  This gives the user the choice,
+  # since otherwise there would be no reason to specify 'o_e' *and* 'm_e'.
+  # Fallback to UTF-8 since it is a reasonable default these days.
+
+  return $self->detected_encoding || $self->output_encoding || 'UTF-8'
+    if $self->match_encoding;
+
+  # If output encoding wasn't specified, return false.
+  return $self->output_encoding;
 }
 
 ## Blocks ##
@@ -457,7 +733,8 @@ sub   _end_head {
 
 ## Lists ##
 
-# TODO: over_empty
+# With Pod::Simple->parse_empty_lists(1) there could be an over_empty event,
+# but what would you do with that?
 
 sub _start_list {
   my ($self) = @_;
@@ -478,7 +755,6 @@ sub   _end_list {
   # but don't end with a double newline.
   my $text = $self->_chomp_all($self->_pop_stack_text);
 
-  # FIXME:
   $_[0]->_save_line($text . $/);
 }
 
@@ -512,7 +788,11 @@ sub _start_item {
 
 sub   _end_item {
   my ($self, $marker) = @_;
-  $self->_save_line($self->_indent($marker . ' ' . $self->_pop_stack_text));
+  my $text = $self->_pop_stack_text;
+  $self->_save_line($self->_indent($marker .
+    # Add a space only if there is text after the marker.
+    (defined($text) && length($text) ? ' ' . $text : '')
+  ));
 
   # Store any possible contents in a new stack (like a sub-document).
   $self->_increase_indent;
@@ -811,24 +1091,15 @@ sub format_fragment_markdown {
   # The strings gets passed through encode_entities() before idify().
   # If we don't do it here the substitutions below won't operate consistently.
 
-  # encode_entities {
-    my %entities = (
-      q{>} => 'gt',
-      q{<} => 'lt',
-      q{'} => '#39',
-      q{"} => 'quot',
-      q{&} => 'amp',
-    );
-
-    my
-      $ents = join '', keys %entities;
-  # }
-
   sub format_fragment_pod_simple_xhtml {
     my ($self, $t) = @_;
 
     # encode_entities {
-      $t =~ s/([$ents])/'&' . ($entities{$1} || sprintf '#x%X', ord $1) . ';'/ge;
+      # We need to use the defaults in case html_encode_chars has been customized
+      # (since the purpose is to match what external sources are doing).
+
+      local $self->_private->{html_encode_chars};
+      $t = $self->encode_entities($t);
     # }
 
     # idify {
@@ -883,10 +1154,9 @@ __END__
 =encoding UTF-8
 
 =for :stopwords Marcel Gruenauer Victor Moral Ryan C. Thompson <rct at thompsonclan d0t
-org> Aristotle Pagaltzis Randy Stauner ACKNOWLEDGEMENTS Vereshagin Yasutaka
-ATARASHI motemen moznion Cindy Wang (CindyLinz) Graham Ollis Mike Covington
-Peter html cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee
-diff irc mailto metadata placeholders metacpan
+org> Aristotle Pagaltzis Randy Stauner ACKNOWLEDGEMENTS html cpan
+testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto
+metadata placeholders metacpan
 
 =head1 NAME
 
@@ -894,7 +1164,7 @@ Pod::Markdown - Convert POD to Markdown
 
 =head1 VERSION
 
-version 2.002
+version 3.000
 
 =head1 SYNOPSIS
 
@@ -911,11 +1181,6 @@ version 2.002
 
   # See Pod::Simple docs for more.
 
-  # Legacy (Pod::Parser-based) API is supported for backward compatibility:
-  my $parser = Pod::Markdown->new;
-  $parser->parse_from_filehandle(\*STDIN);
-  print $parser->as_markdown;
-
 =head1 DESCRIPTION
 
 This module uses L<Pod::Simple> to convert POD to Markdown.
@@ -933,6 +1198,28 @@ To change which regions are accepted use the L<Pod::Simple> API:
   my $parser = Pod::Markdown->new;
   $parser->unaccept_targets(qw( markdown html ));
 
+=head2 A note on encoding and escaping
+
+The common L<Pod::Simple> API returns a character string.
+If you want Pod::Markdown to return encoded octets, there are two attributes
+to assist: L</match_encoding> and L</output_encoding>.
+
+When an output encoding is requested any characters that are not valid
+for that encoding will be escaped as HTML entities.
+
+This is not 100% safe, however.
+
+Markdown escapes all ampersands inside of code spans, so escaping a character
+as an HTML entity inside of a code span will not be correct.
+However, with pod's C<S> and C<E> sequences it is possible
+to end up with high-bit characters inside of code spans.
+
+So, while C<< output_encoding => 'ascii' >> can work, it is not recommended.
+For these reasons (and more), C<UTF-8> is the default, fallback encoding (when one is required).
+
+If you prefer HTML entities over literal characters you can use
+L</html_encode_chars> which will only operate outside of code spans (where it is safe).
+
 =head1 METHODS
 
 =head2 new
@@ -1040,6 +1327,62 @@ Default is false.
 
 =back
 
+=head2 html_encode_chars
+
+A string of characters to encode as html entities
+(using L<HTML::Entities/encode_entities> if available, falling back to numeric entities if not).
+
+Possible values:
+
+=over 4
+
+=item *
+
+A value of C<1> will use the default set of characters from L<HTML::Entities> (control chars, high-bit chars, and C<< <&>"' >>).
+
+=item *
+
+A false value will disable.
+
+=item *
+
+Any other value is used as a string of characters (like a regular expression character class).
+
+=back
+
+By default this is disabled and literal characters will be in the output stream.
+If you specify a desired L</output_encoding> any characters not valid for that encoding will be HTML entity encoded.
+
+B<Note> that Markdown requires ampersands (C<< & >>) and left angle brackets (C<< < >>)
+to be entity-encoded if they could otherwise be interpreted as html entities.
+If this attribute is configured to encode those characters, they will always be encoded.
+If not, the module will make an effort to only encode the ones required,
+so there will be less html noise in the output.
+
+=head2 match_encoding
+
+Boolean: If true, use the C<< =encoding >> of the input pod
+as the encoding for the output.
+
+If no encoding is specified, L<Pod::Simple> will guess the encoding
+if it sees a high-bit character.
+
+If no encoding is guessed (or the specified encoding is unusable),
+L</output_encoding> will be used if it was specified.
+Otherwise C<UTF-8> will be used.
+
+This attribute is not recommended
+but is provided for consistency with other pod converters.
+
+Defaults to false.
+
+=head2 output_encoding
+
+The encoding to use when writing to the output file handle.
+
+If neither this nor L</match_encoding> are specified,
+a character string will be returned in whatever L<Pod::Simple> output method you specified.
+
 =head2 man_url_prefix
 
 Returns the url prefix in use for man pages.
@@ -1063,11 +1406,6 @@ to an internal section in this document.
 Returns the boolean value indicating
 whether or not meta tags will be printed.
 
-=head2 as_markdown
-
-Returns the parsed POD as Markdown. Takes named arguments. If the C<with_meta>
-argument is given a positive value, meta tags are generated as well.
-
 =head2 format_man_url
 
 Used internally to create a url (using L</man_url_prefix>)
@@ -1117,9 +1455,12 @@ Format fragment for L<search.cpan.org>
 =for Pod::Coverage parse_from_file
 parse_from_filehandle
 
+=for Pod::Coverage as_markdown
+
 =for Pod::Coverage handle_text
 end_.+
 start_.+
+encode_entities
 
 =for test_synopsis my ($pod_string);
 
@@ -1177,7 +1518,7 @@ L<http://metacpan.org/release/Pod-Markdown>
 =head2 Bugs / Feature Requests
 
 Please report any bugs or feature requests by email to C<bug-pod-markdown at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Pod-Markdown>. You will be automatically notified of any
+the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=Pod-Markdown>. You will be automatically notified of any
 progress on the request by the system.
 
 =head2 Source Code
@@ -1215,6 +1556,8 @@ Randy Stauner <rwstauner@cpan.org>
 
 =head1 CONTRIBUTORS
 
+=for stopwords Aristotle Pagaltzis Cindy Wang (CindyLinz) Graham Ollis Mike Covington motemen moznion Peter Vereshagin Ryan C. Thompson Yasutaka ATARASHI
+
 =over 4
 
 =item *
@@ -1235,6 +1578,14 @@ Mike Covington <mfcovington@gmail.com>
 
 =item *
 
+motemen <motemen@cpan.org>
+
+=item *
+
+moznion <moznion@cpan.org>
+
+=item *
+
 Peter Vereshagin <veresc@cpan.org>
 
 =item *
@@ -1245,19 +1596,13 @@ Ryan C. Thompson <rthompson@cpan.org>
 
 Yasutaka ATARASHI <yakex@cpan.org>
 
-=item *
-
-motemen <motemen@cpan.org>
-
-=item *
-
-moznion <moznion@cpan.org>
-
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2004 by Marcel Gruenauer.
+This software is copyright (c) 2009-2011 by Marcel Gruenauer.
+
+This software is copyright (c) 2011 by Randy Stauner.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
